==> mergeant-0.50.tar.gz: mergeant-0.50/libmergeant/marshal.h <==

#ifndef __marshal_MARSHAL_H__
#define __marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:VOID (marshal.list:25) */
#define marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:VOID,VOID (marshal.list:26) */
extern void marshal_VOID__VOID_VOID (GClosure     *closure,
                                     GValue       *return_value,
                                     guint         n_param_values,
                                     const GValue *param_values,
                                     gpointer      invocation_hint,
                                     gpointer      marshal_data);

/* VOID:POINTER (marshal.list:27) */
#define marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

/* VOID:POINTER,POINTER (marshal.list:28) */
extern void marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* VOID:POINTER,UINT,UINT (marshal.list:29) */
extern void marshal_VOID__POINTER_UINT_UINT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* VOID:BOOLEAN (marshal.list:30) */
#define marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN

/* VOID:ULONG (marshal.list:31) */
#define marshal_VOID__ULONG	g_cclosure_marshal_VOID__ULONG

/* VOID:OBJECT (marshal.list:32) */
#define marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT

/* VOID:STRING,STRING (marshal.list:33) */
extern void marshal_VOID__STRING_STRING (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);

/* VOID:STRING,POINTER (marshal.list:34) */
extern void marshal_VOID__STRING_POINTER (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* VOID:STRING,UINT (marshal.list:35) */
extern void marshal_VOID__STRING_UINT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);

G_END_DECLS

#endif /* __marshal_MARSHAL_H__ */

==> mergeant_0.52.orig.tar.gz: mergeant-0.52/libmergeant/marshal.h <==

#ifndef __marshal_MARSHAL_H__
#define __marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:VOID (marshal.list:25) */
#define marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:VOID,VOID (marshal.list:26) */
extern void marshal_VOID__VOID_VOID (GClosure     *closure,
                                     GValue       *return_value,
                                     guint         n_param_values,
                                     const GValue *param_values,
                                     gpointer      invocation_hint,
                                     gpointer      marshal_data);

/* VOID:POINTER (marshal.list:27) */
#define marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

/* VOID:POINTER,POINTER (marshal.list:28) */
extern void marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* VOID:POINTER,UINT,UINT (marshal.list:29) */
extern void marshal_VOID__POINTER_UINT_UINT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* VOID:BOOLEAN (marshal.list:30) */
#define marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN

/* VOID:ULONG (marshal.list:31) */
#define marshal_VOID__ULONG	g_cclosure_marshal_VOID__ULONG

/* VOID:OBJECT (marshal.list:32) */
#define marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT

/* VOID:OBJECT,BOOL (marshal.list:33) */
extern void marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);
#define marshal_VOID__OBJECT_BOOL	marshal_VOID__OBJECT_BOOLEAN

/* VOID:INT (marshal.list:34) */
#define marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:STRING,STRING (marshal.list:35) */
extern void marshal_VOID__STRING_STRING (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);

/* VOID:STRING,POINTER (marshal.list:36) */
extern void marshal_VOID__STRING_POINTER (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* VOID:STRING,UINT (marshal.list:37) */
extern void marshal_VOID__STRING_UINT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);

G_END_DECLS

#endif /* __marshal_MARSHAL_H__ */
